bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 27. Aventiure
___________________________________________________ #### Auentv wie der marchrave die kunige mit ir rechen in #### sin hvs enpfie vn– wier ir sit pflach
| ### <In> solhen unmvzen svln wir die frowen lan ### hie wart vil michel gahen vber velt getan ### von Rvdegeres frivnden da man die geste vant ### si wrden [59v]wol enpfangen in des marcgraven lant ### Do si der marcgrave zvo zim chomen sach ### Rvdeger der snelle wie vrolich er sprach ### sit willechomen ir herren vn– ovch iwer man ### hie in disem lande wie gern ih ivch gesehn han
###### 1696 | ### Do danchtem im die rechen mit triwen ane haz ### daz er in willechomen wære vil wol erzeichter daz ### svnder grvozter Hagenen den het er <ê> bechant ### sam tet er Volkeren den helt von Burgonden lant
###### 1697 | ### Do sprach zem marcgraven Danchwart der degen ### sit ir vns welt bervochen wer sol vns danne pflegen ### des vnsern ingesindes von Wormez vber Rin ### do sprach der marcgrave die angest svlt ir lazen sin
###### 1698 | ### Ez wirdet wol behalden swaz ir in daz lant ### habt mit iv gefvret ros silber vn– gewant ### dem schaffe ich <solhe> hvte daz sin wirt niht verlorn ### daz iv ze schaden bringe gegen einem halben sporn
| ### Spannet vf ir knehte die hvtten an daz velt ### swaz ir hie verlieset des wil ich wesen gelt ### vn– ziehet abe die zovme div ros div lazet gan ### daz het in wirt deheiner da vor vil selten getan
###### 1700 | ### Des frevten sich die geste do daz geschaffen was ### die herren riten dannen sich leiten in daz gras ### vber al die knehte si heten gvot gemach ### ich wæn in an der verte nie so sanfte geschach
###### 1701 | ### Nv was div marcgrauinne fvr daz tor gegan ### mit ir vil schonen tohter do sah man bi ir stan ### die <minneklichen> frowen vn– manige schone meit ### die trvgen vil der boege vn– oech die herlichen chleit
###### 1702 | ### Daz edele gesteine verre lvhte von in dan ### vz ir vil richen wæte die warn wol getan ### do chomen ovch die rechen vn– erbeizten sa zehant ### hey waz man grozer zvehte an den Burgonden vant
###### 1703 | ### Sehs vn– drizzech meide vn– ander manic wip ### den was ze wnsche schone vn– minneklich der lip ### die giengen in engegene vn– wolden si enpfan ### da wart ein schone grvzen von den frowen getan
| ### Div ivnge marcgrauinne chvste die kunige dri ### alsam tet ir mvter da stvnt ovch Hagen bi ### den bat ir vater chvssen do blicte si in an ### er dvhte si so gremlich daz siz gerne hete lan
###### 1705 | ### Doch mvste si da leisten daz ir der wirt gebot ### gemisschet wart ir varwe bleich vn– rot ### si chvste oech Danchwarten dar nach den spileman ### durch sines libes ellen wart im daz grvzen getan
###### 1706 | ### Div iunge marcgravinne nam do bi der hant ### Giselhern den rechen von Burgonden lant ### alsam tet ir mvoter Gunthern den chvnen man ### Gernoten fvrte Rvdeger mit in minnechlichen dan
###### 1707 | ### In der schonen buorge stvnt ein witer sal ### ritter vn– frowen gesazen da zetal ### do hiez man balde schenchen den gesten gvten [60r]win ### ez endorften nimmer helede gehandelt gvetlicher sin
###### 1708 | ### Mit lieben ovgen blichen wart vil gesehn an ### div Rvdegeres tohter do was so wolgetan ### ia trvotes in dem hercen vil manic ritter gvot ### daz chunde ovch si verdienen si was vil hohe gemvot
###### 1709 | ### Si gedahten swes si wolden es enmoht aber niht geschehn ### an mægede vn– oech an frowen wart da vil gesehn ### fvr vn– widere wande ir saz da genvoc ### der edel videlære dem wirte holden willen trvoc
| ### Nach gewonheite do schieden si sich da ### ritter vn– frowen die giengen anderswa ### do rihte man die tische in demn sale wit ### den vil lieben gesten man diente willekliche sit
###### 1711 | ### Dvrch der geste liebe hin ze tische gie ### niwan div marcgravinne ir tohter si do lie ### beliben bi den kinden da si von rehte saz ### daz si ir niht ensahen die geste mvete sere daz
###### 1712 | ### Do si mit frevden heten gegezzen vber al ### do wiste man die schonen wider in den sal ### gæmelicher spruoche der wart da niht verdeit ### der reit vil da Volker ein degen chven vn– gemeit
###### 1713 | ### Do sprach offenliche der tivre spileman ### vil richer marcgrave got hat an iv getan ### vil genædekliche daz er iv hat gegeben ### ein wip so rehte schoene dar zvo ein wnneklichez lebn
###### 1714 | ### Ob ich ein fvrste wære sprach aber der spileman ### vn– solde ich tragen chrone ze wibe wolde ich han ### die iwern schonen tohter des wonnet mir der mvot ### div ist minneklich ze sehene dar zvo edel vn– gvot
| ### Do sprach der marcgrave wie moehte daz gesin ### daz immer kunic gegerte der lieben tohter min ### wir sin beide ellende ich vn– ovch min wip ### vn– haben niht ze gebene waz hilfet danne ir schoner lip
###### 1716 | ### Do sprach der herre Gernot ir svlt die rede lan ### vn– solde ich trvttinne nach mime willen han ### ane gvot ze wibe wær ich ir immer vro ### des antwrte Hagene vil harte minneklichen do
###### 1717 | ### Nv sol doch her Giselher min herre nemen wip ### ez ist so hoher mage der marcgravinne lip ### daz wir ir dienten gerne ich vn– ander iwer man ### vn– soldes under chrone da zen Burgonden gan
###### 1718 | ### Div rede Rvdegeren von in dvhte gvot ### vn– ovch die marcgrauinne ia frevtez in den mvot ### sit trvgen an die helde daz si ze wibe nam ### Giselher der edele wandez in beiden wol gezam
###### 1719 | ### Swaz sich sol gefvgen wer mac daz vndersten ### man bat die ivncfrowen hin ze hove gen ### do swor man im ze gebene daz wnnekliche kint ### oech lobt er ze nemene die vil <minneklichen> sint
| ### Man beschiet der ivncfrowen bvrge vn– lant ### des sichert da mit eiden des richen chuniges hant ### vn– Gernot der herre daz wrde daz getan ### do sprach der marcgrave sit ich der lande niht enhan
###### 1721 | ### sone lat iv niht versmahen min ellendes solt ### ich gibe [60v]zv miner tohter silber un– golt ### swaz zwei hvndert moere meiste mvgen getragen ### div rede mvste den degenen beidenthalben wol behagen
###### 1722 | ### Nach gewonheite man hiez an einen rinch ### sten die minneklichen manec sneller ivngelinch ### in gezweietem mvote ir ze gegene stvnt ### si gedahten in ir sinne so noch die tvmben dicke tvont
###### 1723 | ### Do man begunde vragen die minneklichen meit ### ob si den rechen wolde ein teil was ez ir leit ### vn– dahte doch ze nemene den wætlichen man ### si schamte sich der vrage so manic maget hat getan
###### 1724 | ### Ir rvonte ir vater Rvdeger daz si spræche ia ### vn– in vil gerne næme vil schiere was do da ### mit sinen wizen handen der si do vnbesloz ### Giselher der ivnge swie lvzzil si des sit genoz
###### 1725 | ### Do sprach der marcgrave ir edeln kunige rich ### als ir nv wider wendet daz ist gewonlich ### heim zvo zivren landen so gib ich iv min kint ### daz ir si mit iv fvret daz gelobten si sint
| ### Swaz man da schalles horte den mvsen si doch lan ### man hiez die iuncfrowen zir kemenaten gan ### vn– oech die geste slafen si erbiten an den tac ### do bereite man die spise der wirt ir minneklichen pflac
###### 1727 | ### Do si nv gezzen heten vn– wolden dannen varn ### gein der Hvnen landen daz heiz ich wol bewarn ### sprach der wirt vil edele ir svlt noch hie bestan ### wande ich so lieber geste selten her gewnnen han
###### 1728 | ### Des antwrte Danchwart iane mages niht gesin ### wa næmet ir die spise daz brot vn– ovch den win ### daz so manigem manne wære hie bereit ### do daz der wirt gehorte ez was im ane maze leit
###### 1729 | ### Do sprach der marcgrave div rede ist ane not ### ze vierzehen nêhten win vn– brot ### gêbe ich iv voelleklichen mit den die ir noch hie hat ### ir mvzet hie beliben des ist deheiner slahte rat
###### 1730 | ### Swie vil si dannen gerten si mvsen da bestan ### vnz an den vierden morgen do wart ovch da getan ### von des wirtes milte daz verre wart geseit ### er gap den sinen gesten beidiv wafen vn– kleit
| ### Ez mohte wern niht langer si mvsen dannen varn ### Rvdeger der chunde vil wenic iht gesparn ### von der sinen milte swes iemen gerte nemen ### daz versagt er niemen ez mvse in allen gezemen
###### 1732 | ### Daz edel ingesinde brahte fvr daz tor ### gesatelt vil der rosse do warte ovch in da vor ### vil der gvten rechen die trvgen schilde enhant ### wande si riten wolden nider in der Hunen lant
###### 1733 | ### Der wirt do sine gabe bot vber al ### e daz die edeln geste choemen fvr den sal ### er chvnde miltekliclhe mit grozen eren lebn ### die sine schonen tohter die het er Giselher gegebn
###### 1734 | ### Do gab er Gvnthere dem helde lobelich ### daz wol trvoc mit eren der edel kunic rich ### swier [61r]nie gabe enpfienge ein waffenlich gewant ### do neich der fvrste here des milten Rvdegers hant
###### 1735 | ### Do gab er Gernote ein wafen gvot genvoc ### daz er sit in stvrmen vil herlichen trvoch ### der gabe im vil wol gvnde des marcgraven wip ### da von der gvte Rvdeger mvse vliesen sit den lip
| ### Do bot div marcgrauinne Hagen ir gabe alsam ### mit bete minnekliche sit si der kunec nam ### daz er ane ir stivre zvo der hochgecit ### varn niene solde der helt gelobt ez ane strit
###### 1737 | ### Alles des ich ie gesach sprach do Hagene ### sone gerte ich niht mere nv ze habene ### niwan ienes schildes der dort hanget an der want ### den wolde ich gerne fvren mit mir in der Hvnen lant
| ### Do div marcgrauinne Hagen bete vernam ### ez mante si ir leide weinen si gezam ### do gedahte si vil tivre an Nuodvnges tot ### den het erslagen Witege des twanc si iæmerlichiv not
###### 1739 | ### Si sprach zvo dem degene den schilt wil ich iv gebem ### daz wolde got von himele daz er noh solde leben ### der in da trvg enhende der lag in stvrme tot ### den mvz ich immer weinen des gat mir <armen> wibe not
###### 1740 | ### Div edel marcgravinne von ir sedele gie ### bi dem schilt vezzil si den schilt gevie ### do brahte si in Hagene si selbe mit ir hant ### div gabe was mit eren an den rechen gewant
###### 1741 | ### Ein hvlft von liehtem pfelle ob siner varwe lac ### bezzer schilt deheinen belvhte nie der tac ### von edelm gesteine swers ze chovfen hete gegert ### oder in veil hete er was wol tvsint marche wert
###### 1742 | ### Den schilt hiez do Hagene von im tragen dan ### do chom sin brvder Danchwart hin ze hove gegan ### dem gap vil richiv chleider des marcgraven kint ### die er da zen Hvnen trvoc vil herlichen sint
| ### Allez daz der gabe von in da wart genomen ### in ir deheines hende wær ir niht bechomen ### wan dvrch des wirtes liebe derz in so schone erbot ### sit wrdens im so vint daz si in mvsen slahen tot
###### 1744 | ### Volker mit siner videlen dan ### chom gezogenliche fvr Gotelinde stan ### er videlt sveze done vn– sang ir siniv liet ### da mite nam er vrlovp do er von Bechelaren sciet
###### 1745 | ### Ir hiez div marcgravinne eine lade tragen ### von frivntlicher gabe mveget ir nv horen sagen ### dar vz si nam sehs povge vn– spiens im an die hant ### die svlt ir fvren Volker von mir in der Hunen lant
###### 1746 | ### vn– svlt dvrch minen willen si da ze hove tragen ### swenne ir wider wendet daz man mir mvge sagen ### wie ir mir habt gedienet da zer hochgecit ### des si zem rechen gerte vil wol gewert er sis sit
###### 1747 | ### Do sprach der wirt zen gesten ir svlt dest sanfter varn ### ich wil ivch selbe leiten vn– heizen wol bewarn ### daz man [61v]iv vf der strazen nêm deheiniv pfant ### ich sol ivch selbe leiten in daz Ezelen lant
| ### Der wirt wart wol bereit mit fvnf hundert man ### ze rossen vn– ze chleidern die fvrt er mit im dan ### in vrolichem mvote zv der hochgecit ### der deheiner nimmer mere chom ze Bechelaren sit
###### 1749 | ### Mit chvsse minnekliche der wirt do dannen schiet ### also tet ovch Giselher als im div liebe riet ### mit vnbeslozzen armen si trvten schoeniv wip ### daz mvose sit bewæinen vil maniger ivncfrowen lip
###### 1750 | ### Vil venster wart entslozzen vn– wit vf getan ### der wirt mit sinen mannen zen rossen wolde gan ### in wæn ir hercen sageten div chrefteklichen ser ### daz si der lieben <frivnde> dar nach gesahen nimmer mer
###### 1751 | ### Nach ir lieben frivnden heten genvge leit ### do weinten ane maze vil frowen vn– manic meit ### doch riten si mit frevden nider vber sant ### zetal bi Tvonowe vnz in daz hunische lant
| ### Do sprach zen Bvrgonden der ritter vnverzaget ### Rvdeger der edele ia svln niht sin verdaget ### Ezeln disiv mære daz wir zen Hvnen chomen ### vn– oech mine frowen sine hant so liebes niht vernomen
###### 1753 | ### Ze tal dvrch Oestiriche vil manec bote reit ### den lvten allenthalben wart daz wol geseit ### daz die herren choemen von Wormez vber Rin ### dem Ezeln ingesinde chunde niht lieber gesin
###### 1754 | ### Die boten fvr strichen mit disen mæren ### daz die Nibelunge zen Hvnen wæren ### dv solt si wol enpfahen Chriemh' frowe min ### dir choment nach grozen eren her die stolzen brveder din
###### 1755 | ### Do div kuniginne vernam div mære ### ir begunde entwichen ein teil ir swære ### von ir vater lande chom ir vil manic man ### da von der kunic Ezele vil manigen iamer <sit> gewan
###### 1756 | ### Si gedahte tovgenliche noch mohte is werden rat ### der mich an minen frevden also gepfendet hat ### mag ich daz gefvgen ez sol im leide ergan ### ze dirre hochgecite des ich vil gvten willen han
###### 1757 | ### Ich solz also schaffen daz min rache erge ### in dirre hochgecite swiez dar nach geste ### an sinem argen libe der mir hat benomen ### vil der minen wnne des sol ich nv ze gelte chomen

<<< Übersicht <<< vorige Seite nächste Seite >>>